@@ -371,92 +371,92 @@ def update_remote_task(service, TASKLIST1, local_dict, tasklist_title, task_titl
     except HttpError as err:
         print(f"Failed to update task '{task_title}': {err}")
 
-# ================================================================================
-# MAIN
-# --------------------------------------------------------------------------------
+# # ================================================================================
+# # MAIN
+# # --------------------------------------------------------------------------------
 
-#@click.command()
-#@click.argument("command")
-##@click.option("--command", "-c", default="rprint", help="rprint  lprint  rlcomp")
-def main(command):
-    """Shows basic usage of the Tasks API.
-    Prints the title and ID of the first 10 task lists.
-    """
-    creds = None
-    # The file token.json stores the user's access and refresh tokens, and is
-    # created automatically when the authorization flow completes for the first
-    # time.
-    if os.path.exists(TOKEN):
-        creds = Credentials.from_authorized_user_file(TOKEN, SCOPES)
-    # If there are no (valid) credentials available, let the user log in.
-    if not creds or not creds.valid:
-        print(f"D...  TOKEN: {TOKEN}")
-        if creds and creds.expired and creds.refresh_token:
-            creds.refresh(Request())
-        else:
-            flow = InstalledAppFlow.from_client_secrets_file(
-                    CRED, SCOPES
-            )
-            creds = flow.run_local_server(port=0)
-        # Save the credentials for the next run
-        with open(TOKEN, "w") as token:
-            token.write(creds.to_json())
+# #@click.command()
+# #@click.argument("command")
+# ##@click.option("--command", "-c", default="rprint", help="rprint  lprint  rlcomp")
+# def main(command):
+#     """Shows basic usage of the Tasks API.
+#     Prints the title and ID of the first 10 task lists.
+#     """
+#     creds = None
+#     # The file token.json stores the user's access and refresh tokens, and is
+#     # created automatically when the authorization flow completes for the first
+#     # time.
+#     if os.path.exists(TOKEN):
+#         creds = Credentials.from_authorized_user_file(TOKEN, SCOPES)
+#     # If there are no (valid) credentials available, let the user log in.
+#     if not creds or not creds.valid:
+#         print(f"D...  TOKEN: {TOKEN}")
+#         if creds and creds.expired and creds.refresh_token:
+#             creds.refresh(Request())
+#         else:
+#             flow = InstalledAppFlow.from_client_secrets_file(
+#                     CRED, SCOPES
+#             )
+#             creds = flow.run_local_server(port=0)
+#         # Save the credentials for the next run
+#         with open(TOKEN, "w") as token:
+#             token.write(creds.to_json())
 
-    TASKLIST = {}
-    try:
-        service = build("tasks", "v1", credentials=creds)
+#     TASKLIST = {}
+#     try:
+#         service = build("tasks", "v1", credentials=creds)
 
-        # Call the Tasks API
-        results = service.tasklists().list(maxResults=10).execute()
-        items = results.get("items", [])
+#         # Call the Tasks API
+#         results = service.tasklists().list(maxResults=10).execute()
+#         items = results.get("items", [])
 
-        if not items:
-            print("No task lists found.")
-            return
+#         if not items:
+#             print("No task lists found.")
+#             return
 
-        #print("D... ===============================Task lists:")
-        for item in items:
-            #print(f"D...   * {item['title']} ({item['id']})")
-            TASKLIST[item['id']] = item['title']
-    except HttpError as err:
-        print(err)
+#         #print("D... ===============================Task lists:")
+#         for item in items:
+#             #print(f"D...   * {item['title']} ({item['id']})")
+#             TASKLIST[item['id']] = item['title']
+#     except HttpError as err:
+#         print(err)
 
-    # ===========================================================   command section ============
-    if command == "rprint" or command == "r": # I NEED THIS TO CREATE ORGMODE AGENDA
-        tarem = tasks_read_remote(service, TASKLIST)
-        #print(tarem)
-        print()
-        for i in dict2org(tarem): print(i)
-    elif command == "lprint" or command == "l": # I dont need it really - just to see
-        taloc = tasks_read_file()
-        print(taloc)
-        print()
-        for i in dict2org(taloc): print(i)
-        res = org2dict(   dict2org(taloc)  )
-        print()
-        print(res)
-        print()
-        for i in dict2org(res): print(i)
-    elif command == "rlcomp" or command == "rl":
-        tarem = tasks_read_remote(service, TASKLIST)
-        taloc = tasks_read_file()
-        to_push_new, to_update = tasks_compare_rl(tarem, taloc)
-        print("TO PUSH NEW")
-        print(to_push_new)
-        add_tasks_to_remote(service, TASKLIST, taloc, to_push_new)
-        #
-        #print("TO UPDATE")
-        #print(to_update)
-    else:
-        print("X... unknown command ")
+#     # ===========================================================   command section ============
+#     if command == "rprint" or command == "r": # I NEED THIS TO CREATE ORGMODE AGENDA
+#         tarem = tasks_read_remote(service, TASKLIST)
+#         #print(tarem)
+#         print()
+#         for i in dict2org(tarem): print(i)
+#     elif command == "lprint" or command == "l": # I dont need it really - just to see
+#         taloc = tasks_read_file()
+#         print(taloc)
+#         print()
+#         for i in dict2org(taloc): print(i)
+#         res = org2dict(   dict2org(taloc)  )
+#         print()
+#         print(res)
+#         print()
+#         for i in dict2org(res): print(i)
+#     elif command == "rlcomp" or command == "rl":
+#         tarem = tasks_read_remote(service, TASKLIST)
+#         taloc = tasks_read_file()
+#         to_push_new, to_update = tasks_compare_rl(tarem, taloc)
+#         print("TO PUSH NEW")
+#         print(to_push_new)
+#         add_tasks_to_remote(service, TASKLIST, taloc, to_push_new)
+#         #
+#         #print("TO UPDATE")
+#         #print(to_update)
+#     else:
+#         print("X... unknown command ")
 
 
 
 
 
-#@click.group()
-#def cli():
-#    pass
+# #@click.group()
+# #def cli():
+# #    pass
 
 
 # ================================================================================
@@ -522,12 +522,13 @@ def main_import(command="rprint"):
 #  EXPORT MAIN
 # --------------------------------------------------------------------------------
 
-#@click.command()
-#@click.argument('filename',  required=True)
-def main_export(filename, command="rlcomp"):
+@click.command()
+@click.argument('filename',  required=True)
+def main_export(filename):
     """Shows basic usage of the Tasks API.
     Prints the title and ID of the first 10 task lists.
     """
+    command = "rlcomp"
     creds = None
     # The file token.json stores the user's access and refresh tokens, and is
     # created automatically when the authorization flow completes for the first
@@ -618,9 +619,13 @@ def main_export(filename, command="rlcomp"):
     #     print("X... unknown command ")
 
 
-@click.command()
-@click.argument('action')
-@click.argument('filename', default=None)
+# ================================================================================
+# MAIN
+# --------------------------------------------------------------------------------
+
+#@click.command()
+#@click.argument('action')
+#@click.argument('filename', default=None)
 def main(action, filename):
     #print(action)
     if action == 'import':
